#!/usr/bin/env python
# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2022/12/25 22:07
@Description     ：
'''

from abc import ABC, abstractmethod


class ExcelParser(ABC):
    """
    解析Excel数据的接口，返回一个字典，给pyecharts填充数据用
    """
    @abstractmethod
    def getExcelData(self):
        pass


# -*- coding: UTF-8 -*-
'''
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/HYOWV7ImvTXImyYWtwADog
@个人网站      ：www.python-office.com
@代码日期    ：2023/8/9 23:10 
@本段代码的视频说明     ：
'''
from pydatav.core.ImageProcess import ImageProcess

ip = ImageProcess()


def txt2wordcloud(filename: str, color: str, result_file: str):
    ip.txt2wordcloud(filename, color, result_file)


if __name__ == '__main__':
    filename = r'D:\workplace\code\github\pydatav\tests\test_files\txt2wordcloud\test.txt'
    color = 'black'
    result_file = r'D:\workplace\code\github\pydatav\tests\test_files\txt2wordcloud\res.jpg'
    txt2wordcloud(filename, color, result_file)



# #!/usr/bin/env python
# # -*- coding:utf-8 -*-
#
# #############################################
# # File Name: flask_web.py
# # 公众号/B站/小红书/抖音: 程序员晚枫
# # Mail: 1957875073@qq.com
# # Created Time:  2022-11-25 10:17:34
# # Description: 有关flask的datav操作
# #############################################
#
# from flask import Flask, render_template
#
# # import config
#
# app = Flask(__name__)
#
#
# # app.config.from_object(config)
#
#
# @app.route('/flask_demo')
# def index():
#     """
#
#     Returns:
#
#     """
#     return render_template('../resources/templates/index.html')
#
#
# if __name__ == '__main__':
#     app.run()



# -*- coding: UTF-8 -*-
'''
@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/HYOWV7ImvTXImyYWtwADog
@个人网站      ：www.python-office.com
@代码日期    ：2023/8/9 22:50 
@本段代码的视频说明     ：
'''
import jieba
# 生成词云需要使用的类库
from wordcloud import WordCloud


class ImageProcess:
    def txt2wordcloud(self, filename: str, color: str, result_file: str):
        """
        @Author & Date  : CoderWanFeng 2022/4/28 9:26
        @Desc  : 生成词云的代码，可以添加更多个性化功能
        @Return  ：
        """
        # print("txt2wordcloud，该功能已过期")

        with open(filename, encoding='utf8') as fp:
            text = fp.read()
            # 将读取的中文文档进行分词
            # 接收分词的字符串
            word_list = jieba.cut(text)
            # 分词后在单独个体之间加上空格
            cloud_text = " ".join(word_list)

            # 生成wordcloud对象
            wc = WordCloud(background_color=color,
                           max_words=200,
                           min_font_size=15,
                           max_font_size=50,
                           width=400,
                           font_path="msyh.ttc",  # 默认的简体中文字体，没有会报错
                           )
            wc.generate(cloud_text)
            wc.to_file(result_file)



from pydatav.api import flask_web
from pydatav.api import image

print('=' * 30)
print('【python-office库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、全部功能【视频 & 文字】教程：https://www.python-office.com/')
print('2、请+【项目交流群】：http://t.cn/A6SSrID0')
print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/python-office')
print('=' * 30)
